@@ -34,8 +34,8 @@ logger = log_config(logger)
 # Instanciando client s3
 try:
     logger.debug("Instanciando client e resorce s3 via cloudgeass")
-    s3_client = boto3.client("s3")
-    s3_resource = boto3.resource("s3")
+    client = boto3.client("s3")
+    resource = boto3.resource("s3")
 
 except Exception as e:
     logger.error("Erro ao iniciar client e resource s3 utilizando "
@@ -49,3 +49,8 @@ except Exception as e:
        2.1 Definindo funcionalidades comuns
 ---------------------------------------------------
 """
+
+
+# Listando buckets já existentes em uma conta AWS
+def list_buckets(resource=resource):
+    return [b.name for b in resource.buckets.all()]
